from sentience_sdk.configuration import Configuration

class SentienceConfiguration(Configuration):
    """Custom Configuration wrapper for Sentience API with simplified authentication."""
    
    def __init__(self, api_key=None, **kwargs):
        super().__init__(**kwargs)
        if not api_key or not api_key.strip():
            raise ValueError("api_key is required and cannot be empty")
        # Automatically set the Authorization header with Bearer token
        self.api_key['Authorization'] = f"Bearer {api_key}" if not api_key.startswith('Bearer ') else api_key



# coding: utf-8

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sentience_sdk.models.sentience_element_states import SentienceElementStates

class TestSentienceElementStates(unittest.TestCase):
    """SentienceElementStates unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SentienceElementStates:
        """Test SentienceElementStates
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SentienceElementStates`
        """
        model = SentienceElementStates()
        if include_optional:
            return SentienceElementStates(
                is_disabled = True,
                is_checked = True,
                is_expanded = True
            )
        else:
            return SentienceElementStates(
        )
        """

    def testSentienceElementStates(self):
        """Test SentienceElementStates"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from sentience_sdk.models.sentience_applied_filters import SentienceAppliedFilters
from sentience_sdk.models.sentience_interactable_element import SentienceInteractableElement
from sentience_sdk.models.sentience_layout_viewport import SentienceLayoutViewport
from sentience_sdk.models.sentience_proxy_failure import SentienceProxyFailure
from sentience_sdk.models.sentience_render_quality import SentienceRenderQuality
from typing import Optional, Set
from typing_extensions import Self

class SentienceMapModeResponse(BaseModel):
    """
    Response for 'map' mode
    """ # noqa: E501
    mode: StrictStr
    status: StrictStr
    engine: Optional[SentienceRenderQuality] = SentienceRenderQuality.PERFORMANCE
    url: StrictStr
    layout_viewport: Optional[SentienceLayoutViewport] = None
    interactable_elements: List[SentienceInteractableElement]
    timestamp: Optional[datetime] = None
    total_elements_extracted: Optional[StrictInt] = None
    filters_applied: Optional[SentienceAppliedFilters] = None
    proxy_failure: Optional[SentienceProxyFailure] = None
    __properties: ClassVar[List[str]] = ["mode", "status", "engine", "url", "layout_viewport", "interactable_elements", "timestamp", "total_elements_extracted", "filters_applied", "proxy_failure"]

    @field_validator('mode')
    def mode_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['map']):
            raise ValueError("must be one of enum values ('map')")
        return value

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['success', 'error']):
            raise ValueError("must be one of enum values ('success', 'error')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SentienceMapModeResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of layout_viewport
        if self.layout_viewport:
            _dict['layout_viewport'] = self.layout_viewport.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in interactable_elements (list)
        _items = []
        if self.interactable_elements:
            for _item_interactable_elements in self.interactable_elements:
                if _item_interactable_elements:
                    _items.append(_item_interactable_elements.to_dict())
            _dict['interactable_elements'] = _items
        # override the default output from pydantic by calling `to_dict()` of filters_applied
        if self.filters_applied:
            _dict['filters_applied'] = self.filters_applied.to_dict()
        # override the default output from pydantic by calling `to_dict()` of proxy_failure
        if self.proxy_failure:
            _dict['proxy_failure'] = self.proxy_failure.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SentienceMapModeResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "mode": obj.get("mode") if obj.get("mode") is not None else 'map',
            "status": obj.get("status"),
            "engine": obj.get("engine") if obj.get("engine") is not None else SentienceRenderQuality.PERFORMANCE,
            "url": obj.get("url"),
            "layout_viewport": SentienceLayoutViewport.from_dict(obj["layout_viewport"]) if obj.get("layout_viewport") is not None else None,
            "interactable_elements": [SentienceInteractableElement.from_dict(_item) for _item in obj["interactable_elements"]] if obj.get("interactable_elements") is not None else None,
            "timestamp": obj.get("timestamp"),
            "total_elements_extracted": obj.get("total_elements_extracted"),
            "filters_applied": SentienceAppliedFilters.from_dict(obj["filters_applied"]) if obj.get("filters_applied") is not None else None,
            "proxy_failure": SentienceProxyFailure.from_dict(obj["proxy_failure"]) if obj.get("proxy_failure") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sentience_sdk.models.sentience_interactable_element import SentienceInteractableElement

class TestSentienceInteractableElement(unittest.TestCase):
    """SentienceInteractableElement unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SentienceInteractableElement:
        """Test SentienceInteractableElement
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SentienceInteractableElement`
        """
        model = SentienceInteractableElement()
        if include_optional:
            return SentienceInteractableElement(
                id = 56,
                uid = '',
                tag = '',
                role = '',
                text = '',
                selector = '',
                bbox = sentience_sdk.models.bounding_box.BoundingBox(
                    x = 56, 
                    y = 56, 
                    w = 56, 
                    h = 56, ),
                is_visible = True,
                z_index = 56,
                attributes = {
                    'key' : ''
                    },
                states = sentience_sdk.models.element_states.ElementStates(
                    is_disabled = True, 
                    is_checked = True, 
                    is_expanded = True, )
            )
        else:
            return SentienceInteractableElement(
                id = 56,
                tag = '',
                role = '',
                bbox = sentience_sdk.models.bounding_box.BoundingBox(
                    x = 56, 
                    y = 56, 
                    w = 56, 
                    h = 56, ),
                is_visible = True,
        )
        """

    def testSentienceInteractableElement(self):
        """Test SentienceInteractableElement"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from sentience_sdk.models.sentience_output_format import SentienceOutputFormat
from sentience_sdk.models.sentience_reader_mode_response_data import SentienceReaderModeResponseData
from typing import Optional, Set
from typing_extensions import Self

class SentienceReaderModeResponse(BaseModel):
    """
    Response for 'read' mode
    """ # noqa: E501
    mode: StrictStr
    status: StrictStr
    url: StrictStr
    content: StrictStr
    title: Optional[StrictStr] = None
    format: Optional[SentienceOutputFormat] = SentienceOutputFormat.MARKDOWN
    author: Optional[StrictStr] = None
    published_date: Optional[datetime] = None
    word_count: Optional[StrictInt] = None
    reading_time_minutes: Optional[StrictInt] = None
    timestamp: Optional[datetime] = None
    data: Optional[SentienceReaderModeResponseData] = None
    __properties: ClassVar[List[str]] = ["mode", "status", "url", "content", "title", "format", "author", "published_date", "word_count", "reading_time_minutes", "timestamp", "data"]

    @field_validator('mode')
    def mode_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['read']):
            raise ValueError("must be one of enum values ('read')")
        return value

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['success', 'error']):
            raise ValueError("must be one of enum values ('success', 'error')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SentienceReaderModeResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of data
        if self.data:
            _dict['data'] = self.data.to_dict()
        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict['title'] = None

        # set to None if author (nullable) is None
        # and model_fields_set contains the field
        if self.author is None and "author" in self.model_fields_set:
            _dict['author'] = None

        # set to None if published_date (nullable) is None
        # and model_fields_set contains the field
        if self.published_date is None and "published_date" in self.model_fields_set:
            _dict['published_date'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SentienceReaderModeResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "mode": obj.get("mode") if obj.get("mode") is not None else 'read',
            "status": obj.get("status"),
            "url": obj.get("url"),
            "content": obj.get("content"),
            "title": obj.get("title"),
            "format": obj.get("format") if obj.get("format") is not None else SentienceOutputFormat.MARKDOWN,
            "author": obj.get("author"),
            "published_date": obj.get("published_date"),
            "word_count": obj.get("word_count"),
            "reading_time_minutes": obj.get("reading_time_minutes"),
            "timestamp": obj.get("timestamp"),
            "data": SentienceReaderModeResponseData.from_dict(obj["data"]) if obj.get("data") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SentiencePlanTier(str, Enum):
    """
    SentiencePlanTier
    """

    """
    allowed enum values
    """
    FREE = 'free'
    PRO = 'pro'
    ENTERPRISE = 'enterprise'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SentiencePlanTier from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sentience_sdk.models.sentience_map_mode_response import SentienceMapModeResponse

class TestSentienceMapModeResponse(unittest.TestCase):
    """SentienceMapModeResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SentienceMapModeResponse:
        """Test SentienceMapModeResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SentienceMapModeResponse`
        """
        model = SentienceMapModeResponse()
        if include_optional:
            return SentienceMapModeResponse(
                mode = 'map',
                status = 'success',
                engine = 'performance',
                url = '',
                layout_viewport = sentience_sdk.models.layout_viewport.LayoutViewport(
                    width = 56, 
                    height = 56, 
                    device_pixel_ratio = 1.337, ),
                interactable_elements = [
                    sentience_sdk.models.interactable_element.InteractableElement(
                        id = 56, 
                        uid = '', 
                        tag = '', 
                        role = '', 
                        text = '', 
                        selector = '', 
                        bbox = sentience_sdk.models.bounding_box.BoundingBox(
                            x = 56, 
                            y = 56, 
                            w = 56, 
                            h = 56, ), 
                        is_visible = True, 
                        z_index = 56, 
                        attributes = {
                            'key' : ''
                            }, 
                        states = sentience_sdk.models.element_states.ElementStates(
                            is_disabled = True, 
                            is_checked = True, 
                            is_expanded = True, ), )
                    ],
                timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                total_elements_extracted = 56,
                filters_applied = sentience_sdk.models.applied_filters.AppliedFilters(
                    limit = 56, 
                    filter = sentience_sdk.models.element_filter.ElementFilter(
                        min_area = 56, 
                        min_z_index = 56, 
                        allowed_roles = [
                            ''
                            ], 
                        allowed_tags = [
                            ''
                            ], ), ),
                proxy_failure = sentience_sdk.models.proxy_failure.ProxyFailure(
                    failure_reason = '', 
                    domain = '', 
                    fallback_successful = True, )
            )
        else:
            return SentienceMapModeResponse(
                mode = 'map',
                status = 'success',
                url = '',
                interactable_elements = [
                    sentience_sdk.models.interactable_element.InteractableElement(
                        id = 56, 
                        uid = '', 
                        tag = '', 
                        role = '', 
                        text = '', 
                        selector = '', 
                        bbox = sentience_sdk.models.bounding_box.BoundingBox(
                            x = 56, 
                            y = 56, 
                            w = 56, 
                            h = 56, ), 
                        is_visible = True, 
                        z_index = 56, 
                        attributes = {
                            'key' : ''
                            }, 
                        states = sentience_sdk.models.element_states.ElementStates(
                            is_disabled = True, 
                            is_checked = True, 
                            is_expanded = True, ), )
                    ],
        )
        """

    def testSentienceMapModeResponse(self):
        """Test SentienceMapModeResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sentience_sdk.api.sentience_observation_api import SentienceObservationApi


class TestSentienceObservationApi(unittest.TestCase):
    """SentienceObservationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SentienceObservationApi()

    def tearDown(self) -> None:
        pass

    def test_observe(self) -> None:
        """Test case for observe

        Observe and extract web content or element coordinates
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SentienceRenderQuality(str, Enum):
    """
    Rendering engine selection.
    """

    """
    allowed enum values
    """
    PERFORMANCE = 'performance'
    PRECISION = 'precision'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SentienceRenderQuality from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sentience_sdk.models.sentience_processing_mode import SentienceProcessingMode

class TestSentienceProcessingMode(unittest.TestCase):
    """SentienceProcessingMode unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSentienceProcessingMode(self):
        """Test SentienceProcessingMode"""
        # inst = SentienceProcessingMode()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictBytes, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from sentience_sdk.models.sentience_interactable_element import SentienceInteractableElement
from sentience_sdk.models.sentience_layout_viewport import SentienceLayoutViewport
from sentience_sdk.models.sentience_proxy_failure import SentienceProxyFailure
from typing import Optional, Set
from typing_extensions import Self

class SentienceVisualModeResponse(BaseModel):
    """
    Response for 'visual' mode
    """ # noqa: E501
    mode: StrictStr
    engine: Optional[StrictStr] = 'precision'
    source: Optional[StrictStr] = None
    status: StrictStr
    url: StrictStr
    layout_viewport: Optional[SentienceLayoutViewport] = None
    interactable_elements: List[SentienceInteractableElement]
    screenshot: Union[StrictBytes, StrictStr]
    screenshot_error: Optional[StrictStr] = None
    timestamp: Optional[datetime] = None
    total_elements_extracted: Optional[StrictInt] = None
    proxy_failure: Optional[SentienceProxyFailure] = None
    __properties: ClassVar[List[str]] = ["mode", "engine", "source", "status", "url", "layout_viewport", "interactable_elements", "screenshot", "screenshot_error", "timestamp", "total_elements_extracted", "proxy_failure"]

    @field_validator('mode')
    def mode_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['visual']):
            raise ValueError("must be one of enum values ('visual')")
        return value

    @field_validator('engine')
    def engine_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['precision']):
            raise ValueError("must be one of enum values ('precision')")
        return value

    @field_validator('source')
    def source_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['precision_visual']):
            raise ValueError("must be one of enum values ('precision_visual')")
        return value

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['success', 'error']):
            raise ValueError("must be one of enum values ('success', 'error')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SentienceVisualModeResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of layout_viewport
        if self.layout_viewport:
            _dict['layout_viewport'] = self.layout_viewport.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in interactable_elements (list)
        _items = []
        if self.interactable_elements:
            for _item_interactable_elements in self.interactable_elements:
                if _item_interactable_elements:
                    _items.append(_item_interactable_elements.to_dict())
            _dict['interactable_elements'] = _items
        # override the default output from pydantic by calling `to_dict()` of proxy_failure
        if self.proxy_failure:
            _dict['proxy_failure'] = self.proxy_failure.to_dict()
        # set to None if screenshot_error (nullable) is None
        # and model_fields_set contains the field
        if self.screenshot_error is None and "screenshot_error" in self.model_fields_set:
            _dict['screenshot_error'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SentienceVisualModeResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "mode": obj.get("mode") if obj.get("mode") is not None else 'visual',
            "engine": obj.get("engine") if obj.get("engine") is not None else 'precision',
            "source": obj.get("source"),
            "status": obj.get("status"),
            "url": obj.get("url"),
            "layout_viewport": SentienceLayoutViewport.from_dict(obj["layout_viewport"]) if obj.get("layout_viewport") is not None else None,
            "interactable_elements": [SentienceInteractableElement.from_dict(_item) for _item in obj["interactable_elements"]] if obj.get("interactable_elements") is not None else None,
            "screenshot": obj.get("screenshot"),
            "screenshot_error": obj.get("screenshot_error"),
            "timestamp": obj.get("timestamp"),
            "total_elements_extracted": obj.get("total_elements_extracted"),
            "proxy_failure": SentienceProxyFailure.from_dict(obj["proxy_failure"]) if obj.get("proxy_failure") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sentience_sdk.models.sentience_observe_request import SentienceObserveRequest

class TestSentienceObserveRequest(unittest.TestCase):
    """SentienceObserveRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SentienceObserveRequest:
        """Test SentienceObserveRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SentienceObserveRequest`
        """
        model = SentienceObserveRequest()
        if include_optional:
            return SentienceObserveRequest(
                url = 'https://news.ycombinator.com',
                mode = 'read',
                format = 'markdown',
                content_limit = 1000,
                options = sentience_sdk.models.observe_options.ObserveOptions(
                    render_quality = 'performance', 
                    limit = 10, 
                    filter = sentience_sdk.models.element_filter.ElementFilter(
                        min_area = 56, 
                        min_z_index = 56, 
                        allowed_roles = [
                            ''
                            ], 
                        allowed_tags = [
                            ''
                            ], ), 
                    viewport = sentience_sdk.models.viewport.Viewport(
                        width = 56, 
                        height = 56, ), ),
                proxy = 'http://user:pass@proxy.example.com:8080'
            )
        else:
            return SentienceObserveRequest(
                url = 'https://news.ycombinator.com',
        )
        """

    def testSentienceObserveRequest(self):
        """Test SentienceObserveRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from sentience_sdk.models.sentience_applied_filters import SentienceAppliedFilters
from sentience_sdk.models.sentience_bounding_box import SentienceBoundingBox
from sentience_sdk.models.sentience_credit_details import SentienceCreditDetails
from sentience_sdk.models.sentience_element_filter import SentienceElementFilter
from sentience_sdk.models.sentience_element_states import SentienceElementStates
from sentience_sdk.models.sentience_error_response import SentienceErrorResponse
from sentience_sdk.models.sentience_insufficient_credits_error import SentienceInsufficientCreditsError
from sentience_sdk.models.sentience_interactable_element import SentienceInteractableElement
from sentience_sdk.models.sentience_layout_viewport import SentienceLayoutViewport
from sentience_sdk.models.sentience_map_mode_response import SentienceMapModeResponse
from sentience_sdk.models.sentience_observe200_response import SentienceObserve200Response
from sentience_sdk.models.sentience_observe_options import SentienceObserveOptions
from sentience_sdk.models.sentience_observe_request import SentienceObserveRequest
from sentience_sdk.models.sentience_output_format import SentienceOutputFormat
from sentience_sdk.models.sentience_plan_tier import SentiencePlanTier
from sentience_sdk.models.sentience_processing_mode import SentienceProcessingMode
from sentience_sdk.models.sentience_proxy_failure import SentienceProxyFailure
from sentience_sdk.models.sentience_reader_mode_response import SentienceReaderModeResponse
from sentience_sdk.models.sentience_reader_mode_response_data import SentienceReaderModeResponseData
from sentience_sdk.models.sentience_render_quality import SentienceRenderQuality
from sentience_sdk.models.sentience_response_metadata import SentienceResponseMetadata
from sentience_sdk.models.sentience_subscription_details import SentienceSubscriptionDetails
from sentience_sdk.models.sentience_subscription_inactive_error import SentienceSubscriptionInactiveError
from sentience_sdk.models.sentience_viewport import SentienceViewport
from sentience_sdk.models.sentience_visual_mode_response import SentienceVisualModeResponse




# coding: utf-8

# flake8: noqa

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.2.0"

# Define package exports
__all__ = [
    "SentienceObservationApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "SentienceAppliedFilters",
    "SentienceBoundingBox",
    "SentienceCreditDetails",
    "SentienceElementFilter",
    "SentienceElementStates",
    "SentienceErrorResponse",
    "SentienceInsufficientCreditsError",
    "SentienceInteractableElement",
    "SentienceLayoutViewport",
    "SentienceMapModeResponse",
    "SentienceObserve200Response",
    "SentienceObserveOptions",
    "SentienceObserveRequest",
    "SentienceOutputFormat",
    "SentiencePlanTier",
    "SentienceProcessingMode",
    "SentienceProxyFailure",
    "SentienceReaderModeResponse",
    "SentienceReaderModeResponseData",
    "SentienceRenderQuality",
    "SentienceResponseMetadata",
    "SentienceSubscriptionDetails",
    "SentienceSubscriptionInactiveError",
    "SentienceViewport",
    "SentienceVisualModeResponse",
]

# import apis into sdk package
from sentience_sdk.api.sentience_observation_api import SentienceObservationApi as SentienceObservationApi

# import ApiClient
from sentience_sdk.api_response import ApiResponse as ApiResponse
from sentience_sdk.api_client import ApiClient as ApiClient
from sentience_sdk.configuration import Configuration as Configuration
from sentience_sdk.exceptions import OpenApiException as OpenApiException
from sentience_sdk.exceptions import ApiTypeError as ApiTypeError
from sentience_sdk.exceptions import ApiValueError as ApiValueError
from sentience_sdk.exceptions import ApiKeyError as ApiKeyError
from sentience_sdk.exceptions import ApiAttributeError as ApiAttributeError
from sentience_sdk.exceptions import ApiException as ApiException

# import models into sdk package
from sentience_sdk.models.sentience_applied_filters import SentienceAppliedFilters as SentienceAppliedFilters
from sentience_sdk.models.sentience_bounding_box import SentienceBoundingBox as SentienceBoundingBox
from sentience_sdk.models.sentience_credit_details import SentienceCreditDetails as SentienceCreditDetails
from sentience_sdk.models.sentience_element_filter import SentienceElementFilter as SentienceElementFilter
from sentience_sdk.models.sentience_element_states import SentienceElementStates as SentienceElementStates
from sentience_sdk.models.sentience_error_response import SentienceErrorResponse as SentienceErrorResponse
from sentience_sdk.models.sentience_insufficient_credits_error import SentienceInsufficientCreditsError as SentienceInsufficientCreditsError
from sentience_sdk.models.sentience_interactable_element import SentienceInteractableElement as SentienceInteractableElement
from sentience_sdk.models.sentience_layout_viewport import SentienceLayoutViewport as SentienceLayoutViewport
from sentience_sdk.models.sentience_map_mode_response import SentienceMapModeResponse as SentienceMapModeResponse
from sentience_sdk.models.sentience_observe200_response import SentienceObserve200Response as SentienceObserve200Response
from sentience_sdk.models.sentience_observe_options import SentienceObserveOptions as SentienceObserveOptions
from sentience_sdk.models.sentience_observe_request import SentienceObserveRequest as SentienceObserveRequest
from sentience_sdk.models.sentience_output_format import SentienceOutputFormat as SentienceOutputFormat
from sentience_sdk.models.sentience_plan_tier import SentiencePlanTier as SentiencePlanTier
from sentience_sdk.models.sentience_processing_mode import SentienceProcessingMode as SentienceProcessingMode
from sentience_sdk.models.sentience_proxy_failure import SentienceProxyFailure as SentienceProxyFailure
from sentience_sdk.models.sentience_reader_mode_response import SentienceReaderModeResponse as SentienceReaderModeResponse
from sentience_sdk.models.sentience_reader_mode_response_data import SentienceReaderModeResponseData as SentienceReaderModeResponseData
from sentience_sdk.models.sentience_render_quality import SentienceRenderQuality as SentienceRenderQuality
from sentience_sdk.models.sentience_response_metadata import SentienceResponseMetadata as SentienceResponseMetadata
from sentience_sdk.models.sentience_subscription_details import SentienceSubscriptionDetails as SentienceSubscriptionDetails
from sentience_sdk.models.sentience_subscription_inactive_error import SentienceSubscriptionInactiveError as SentienceSubscriptionInactiveError
from sentience_sdk.models.sentience_viewport import SentienceViewport as SentienceViewport
from sentience_sdk.models.sentience_visual_mode_response import SentienceVisualModeResponse as SentienceVisualModeResponse


# Sentience Custom Aliases and Wrappers
from sentience_sdk.api_client import ApiClient as SentienceApiClient
from sentience_sdk.sentience_config import SentienceConfiguration
from sentience_sdk.api.sentience_observation_api import SentienceObservationApi



# coding: utf-8

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sentience_sdk.models.sentience_bounding_box import SentienceBoundingBox

class TestSentienceBoundingBox(unittest.TestCase):
    """SentienceBoundingBox unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SentienceBoundingBox:
        """Test SentienceBoundingBox
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SentienceBoundingBox`
        """
        model = SentienceBoundingBox()
        if include_optional:
            return SentienceBoundingBox(
                x = 56,
                y = 56,
                w = 56,
                h = 56
            )
        else:
            return SentienceBoundingBox(
                x = 56,
                y = 56,
                w = 56,
                h = 56,
        )
        """

    def testSentienceBoundingBox(self):
        """Test SentienceBoundingBox"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sentience API

    API Gateway for Sentience Platform - Web Content Extraction and Element Coordinate Mapping

    The version of the OpenAPI document: 1.0.0
    Contact: support@sentienceapi.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sentience_sdk.models.sentience_reader_mode_response import SentienceReaderModeResponse

class TestSentienceReaderModeResponse(unittest.TestCase):
    """SentienceReaderModeResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SentienceReaderModeResponse:
        """Test SentienceReaderModeResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SentienceReaderModeResponse`
        """
        model = SentienceReaderModeResponse()
        if include_optional:
            return SentienceReaderModeResponse(
                mode = 'read',
                status = 'success',
                url = '',
                content = '',
                title = '',
                format = 'markdown',
                author = '',
                published_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                word_count = 56,
                reading_time_minutes = 56,
                timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                data = sentience_sdk.models.reader_mode_response_data.ReaderModeResponse_data(
                    metadata = sentience_sdk.models.response_metadata.ResponseMetadata(
                        engine = 'performance', 
                        used_proxy = True, 
                        proxy_failure = sentience_sdk.models.proxy_failure.ProxyFailure(
                            failure_reason = '', 
                            domain = '', 
                            fallback_successful = True, ), ), )
            )
        else:
            return SentienceReaderModeResponse(
                mode = 'read',
                status = 'success',
                url = '',
                content = '',
        )
        """

    def testSentienceReaderModeResponse(self):
        """Test SentienceReaderModeResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
